@@ -451,7 +451,7 @@ class adam_job():
             self.process_reflectance()
 
 
-            self.define_vza_hotspot()
+            #self.define_vza_hotspot()
             self.process_brdf(do_spectral_averaging=True)
 
 
