@@ -323,6 +323,8 @@ class adam_config():
 
         # - Spectral variation of the foam contribution
         # (see Kokhanovsky A.A. (2004), Spectral reflectance of whitecaps, Journal of Geophysical Research, 109, C05021, doi:10.1029/2003JC002177)
+        if not os.path.exists(os.path.join(self.path_ascii, self.file_ocean_WaterAbs)):
+            raise Exception('Error finding foam datafile at: %s !' % os.path.join(self.path_ascii, self.file_ocean_WaterAbs))
         data = np.loadtxt(os.path.join(self.path_ascii, self.file_ocean_WaterAbs), comments='#', skiprows=0, unpack=True)
         abs_water_foam = data[1,:]
         b_foam = 1.72*1e-3
