@@ -376,7 +376,10 @@ def function_brdf_land_error(ref, cfg, sza=None, vza=None, phi=None,
     # syncronise shapes, this is neccessary because the shape of vza and phi need to always be the same
     vza_meshed, phi_meshed = vza, phi
     if vza.shape != phi.shape:
-        vza_meshed, phi_meshed = np.meshgrid(vza, phi)
+        #        vza_meshed, phi_meshed = np.meshgrid(vza, phi)
+        phi_meshed, vza_meshed = np.meshgrid(phi, vza) # CHANGE_CB
+        vza_meshed = vza_meshed.ravel()                # CHANGE_CB
+        phi_meshed = phi_meshed.ravel()                # CHANGE_CB
 
 
     # BRDF fonctions
@@ -447,7 +450,8 @@ def function_brdf_ocean(ref, wind_speed, cfg, sza=None, vza=None, phi=None, lmbd
     # syncronise shapes, this is neccessary because the shape of vza and phi need to always be the same
     vza_meshed, phi_meshed = vza, phi
     if vza.shape != phi.shape:
-        vza_meshed, phi_meshed = np.meshgrid(vza, phi)
+        #        vza_meshed, phi_meshed = np.meshgrid(vza, phi)
+        phi_meshed, vza_meshed = np.meshgrid(phi, vza) # CHANGE_CB
         vza_meshed = vza_meshed.ravel()
         phi_meshed = phi_meshed.ravel()
 
@@ -637,7 +641,8 @@ def function_brdf_snow( cfg, sza=None, vza=None, phi=None, lmbd=None,
     vza_meshed, phi_meshed = vza, phi
     sza_meshed = sza
     if vza.shape != phi.shape:
-        vza_meshed, phi_meshed = np.meshgrid(vza, phi)
+        #        vza_meshed, phi_meshed = np.meshgrid(vza, phi)
+        phi_meshed, vza_meshed = np.meshgrid(phi, vza) # CHANGE_CB
         vza_meshed = vza_meshed.ravel()
         phi_meshed = phi_meshed.ravel()
         sza_meshed = np.ones(len(vza_meshed))*sza_meshed
@@ -828,7 +833,7 @@ def define_angles_polar_plot( vza, step_polar):
     vza_val = np.linspace(0,vza_max,step_polar)
     phi_val = np.linspace(0,360,step_polar)
     vza_val,phi_val = np.meshgrid(vza_val,phi_val)
-
+    phi_meshed, vza_meshed = np.meshgrid(phi, vza) # CHANGE_CB
 
     return [vza_val.ravel(),phi_val.ravel()]
 # END define_vza
@@ -890,4 +895,3 @@ def ocean_specular_reflectance( ti, n):
     return rho_sp
 # END ocean_specular_reflectance
 # ===================================================================
-
